.. isoenum-webgui documentation master file, created by
   sphinx-quickstart on Thu Aug  1 14:04:19 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to isoenum-webgui's documentation!
==========================================

.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   gui
   cli
   api
   changelog
   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
